@@ -1,16 +1,23 @@
 barNest<-function(formula=NULL,data=NULL,FUN=c("mean","sd"),
- x=NULL,ylim=NULL,main="",xlab="",ylab="",shrink=0.1,errbars=FALSE,
+ ylim=NULL,main="",xlab="",ylab="",shrink=0.1,errbars=FALSE,
  col=NA,labelcex=1,lineht=NA,showall=TRUE,barlabels=NULL,
  showlabels=TRUE,mar=NULL,arrow.cap=0.01,trueval=NA) {
 
- if(is.null(x)) x<-brkdnNest(formula=formula,data=data,FUN=FUN,trueval=trueval)
- else if(!is.list(x)) warning("x is not a list, and this is very unlikely to work")
+ x<-brkdnNest(formula=formula,data=data,FUN=FUN,trueval=trueval)
+ nbn<-length(as.character(attr(terms(formula),"variables")[-1]))
  if(is.null(ylim)) {
   lenx<-length(x)
   if(errbars) {
-   if(lenx == 2) x[[3]]<-x[[2]]
-   ylim<-c(min(unlist(x[[1]])-unlist(x[[2]]),na.rm=TRUE),
-    max(unlist(x[[1]])+unlist(x[[3]]),na.rm=TRUE))
+   errbars<-lenx
+   if(lenx == 3)
+    ylim<-c(min(unlist(x[[3]][[nbn]][,nbn]),na.rm=TRUE),
+     max(unlist(x[[2]][[nbn]][,nbn]),na.rm=TRUE))
+   else {
+    x[[3]]<-x[[2]]
+    ylim<-c(min(unlist(x[[1]][[nbn]][,nbn])-unlist(x[[3]][[nbn]][,nbn]),na.rm=TRUE),
+     max(unlist(x[[1]][[nbn]][,nbn])+unlist(x[[2]][[nbn]][,nbn]),na.rm=TRUE))
+    if(ylim[1] < 0) ylim[1]<-0
+   }
   }
   else {
    funname<-names(x[[1]][[1]])[2]
@@ -29,6 +36,7 @@ barNest<-function(formula=NULL,data=NULL,FUN=c("mean","sd"),
   col=col,labelcex=labelcex,lineht=lineht,showall=showall,
   showlabels=showlabels,arrow.cap=arrow.cap)
  abline(h=0)
+ if(FUN[1]=="valid.n") box()
  if(!is.null(mar)) par(mar=oldmar)
  invisible(x)
 }
